@@ -5,4 +5,6 @@ from . import beam_alignment
 from . import timing_controller
 from . import camera_app_client
 from . import harpia_daq
-from . import fast_daq
\ No newline at end of file
+from . import fast_daq
+from . import laser_clients
+from . import calculate
\ No newline at end of file
