@@ -54,6 +54,9 @@ class Harpia (HTTP_methods):
     
     def wavelength_axis(self):
         return self._get('Basic/WavelengthAxis')    
+    
+    def laser_frequency(self):
+        return self._get('Basic/LaserFrequency')
 
     #==============================================================================
     # /Detectors
@@ -163,12 +166,15 @@ class Harpia (HTTP_methods):
     
     def delay_line_target_delay(self):
         return self._get('DelayLine/TargetDelay')    
-    
+        
     def set_delay_line_target_delay(self, delay):
         self._put('DelayLine/TargetDelay', str(delay))
+    
+    def delay_line_actual_distance(self):
+        return self._get('DelayLine/ActualDistance')
         
-    def delay_line_actual_distance(self, distance):
-        self._put('DelayLine/ActualDistance', str(distance))
+    def set_delay_line_target_distance(self, distance):
+        self._put('DelayLine/TargetDistance', str(distance))
         
     def set_delay_line_target_distance(self, distance):
         self._put('DelayLine/TargetDistance', str(distance))
@@ -513,30 +519,72 @@ class Harpia (HTTP_methods):
     def set_internal_quadrant_detectors_trigger_delay(self, delay):
         return self._put('InternalQuadrantDetectors/ExternalTriggerDelay', str(delay))
     
-    #==============================================================================
+    #===========================================================================
     #     /Microscope
-    #==============================================================================
+    #===========================================================================
     
-    def microscope_camera_alldata(self, index = None):
+    def microscope_camera_alldata(self, index=None):
         return self._get('Microscope/Camera/AllData')
     
+    def microscope_sample_stage_position(self, axis='X', **kwargs):
+        """Get current sample stage XYZ position.
+        
+        Axis must be 'X', 'Y' or 'Z'.
+        """
+        axis = axis.upper()
+        if axis not in ['X', 'Y', 'Z']:
+            raise ValueError("Axis must be X,Y or Z")
+
+        return self._get('Microscope/SampleStagePosition' + axis)
+
     def microscope_sample_stage_position_X(self):
-        return self._get('Microscope/SampleStagePositionX')
-    
-    def microscope_set_sample_stage_position_X(self, position):
-        return self._put('Microscope/SampleStagePositionX', str(position))
+        """Get current sample stage X position."""
+        return self.microscope_sample_stage_position(axis='X')
 
     def microscope_sample_stage_position_Y(self):
-        return self._get('Microscope/SampleStagePositionY')
-    
-    def microscope_set_sample_stage_position_Y(self, position):
-        return self._put('Microscope/SampleStagePositionY', str(position))    
-    
+        """Get current sample stage Y position."""
+        return self.microscope_sample_stage_position(axis='Y')
+
     def microscope_sample_stage_position_Z(self):
-        return self._get('Microscope/SampleStagePositionZ')
+        """Get current sample stage Z position."""
+        return self.microscope_sample_stage_position(axis='Z')
     
-    def microscope_set_sample_stage_position_Z(self, position):
-        return self._put('Microscope/SampleStagePositionZ', str(position))    
+    def microscope_set_sample_stage_position(
+            self, position, axis='X', blocking=True, **kwargs):
+        """Move XYZ sample stage.
+
+        Axis must be 'X', 'Y' or 'Z'.
+
+        The move is blocking, i.e. control is returned after the move is
+        completed. Set 'blocking' to False to just issue the move command
+        without waiting for any feedback. Note that a nonblocking moving
+        command does not even wait for the move to start, so, for example,
+        querrying the speed right after this command to see when the move is
+        done might return a zero because the move hasn't even started yet.
+        """
+        axis = axis.upper()
+        if axis not in ['X', 'Y', 'Z']:
+            raise ValueError("Axis must be X,Y or Z")
+
+        cmd_str = 'Microscope/SampleStagePosition' + axis
+
+        if blocking:
+            cmd_str += 'NonBlocking'
+            
+        return self._put(cmd_str, str(position))
+
+    def microscope_set_sample_stage_position_X(self, position, **kwargs):
+        """Move to sample stage X position."""
+        self.microscope_set_sample_stage_position(position, axis='X', **kwargs)
+
+    def microscope_set_sample_stage_position_Y(self, position, **kwargs):
+        """Move to sample stage Y position."""
+        self.microscope_set_sample_stage_position(position, axis='Y', **kwargs)
+
+    def microscope_set_sample_stage_position_Z(self, position, **kwargs):
+        """Move to sample stage Z position."""
+        self.microscope_set_sample_stage_position(position, axis='Z', **kwargs)
+
 
     #==============================================================================
     #     /MotorizedPumpMirror
